==> haskell-test-framework-hunit-0.3.0.2-230-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-4U3RCIpVsjF3QQkLNtagS5
key:                  test-framework-hunit-0.3.0.2-4U3RCIpVsjF3QQkLNtagS5
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  410d76ae9772361cc736e5ec4e154fe3
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-8.10.4/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/test-framework-hunit-0.3.0.2

hs-libraries:         HStest-framework-hunit-0.3.0.2-4U3RCIpVsjF3QQkLNtagS5
depends:
    HUnit-1.6.2.0-6Qz5k8URKehKv59h9ZmD3M base-4.14.1.0
    extensible-exceptions-0.1.1.4-DY91N4N9LFmCiQpNXwJXMT
    test-framework-0.8.2.0-CpybNBdZ2qSGAJHs6SxlXP

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-hunit-0.3.0.2-238-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-Kb1pNR5XhXUDFs1YaG0Yvs
key:                  test-framework-hunit-0.3.0.2-Kb1pNR5XhXUDFs1YaG0Yvs
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  f8f82b3886cdea3b726a1d0d7b71ae3f
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-8.10.4/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/test-framework-hunit-0.3.0.2

hs-libraries:         HStest-framework-hunit-0.3.0.2-Kb1pNR5XhXUDFs1YaG0Yvs
depends:
    HUnit-1.6.2.0-6Qz5k8URKehKv59h9ZmD3M base-4.14.1.0
    extensible-exceptions-0.1.1.4-DY91N4N9LFmCiQpNXwJXMT
    test-framework-0.8.2.0-19PLWXSnZmu7tI1Urh55QV

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
